/*
 * Copyright (c) Smals
 */

package be.smals.ehealth.etee.domain.identifier;

/**
 * A check digit is a form of redundancy check used for error detection on identification numbers (e.g. bank account
 * numbers) which have been input manually. This interface describes an algorithm that verifies if those check digits
 * are correct.
 *
 * @author matla
 * @since 20141.0.0
 */
public interface CheckDigitAlgorithm {


    /**
     * Verifies if the given identifier is valid for the implementation of the check digit algorithm.
     *
     * @param identifier Identifier that needs to be validated.
     * @return True if the identifier complies with the given check digit algorithm.
     */
    boolean validate(String identifier);

}